@@ -26,7 +26,7 @@
 #ifndef KCONSTANTEDITOR_H
 #define KCONSTANTEDITOR_H
 
-#include "kdialog.h"
+#include <QDialog>
 #include <QValidator>
 
 class Constant;
@@ -38,11 +38,11 @@ class QTreeWidgetItem;
  * Handles all the constants.
  * @author Fredrik Edemar, David Saxton
 */
-class KConstantEditor : public KDialog
+class KConstantEditor : public QDialog
 {
 Q_OBJECT
 public:
-    KConstantEditor(QWidget *parent = 0);
+    explicit KConstantEditor(QWidget *parent = 0);
     ~KConstantEditor();
     
 public slots:
@@ -97,7 +97,7 @@ proper constant letters are used.
 class ConstantValidator : public QValidator
 {
 	public:
-		ConstantValidator( KConstantEditor * parent );
+		explicit ConstantValidator( KConstantEditor * parent );
 		
 		State validate( QString & input, int & pos ) const Q_DECL_OVERRIDE;
 		
